@@ -121,8 +121,8 @@ gboolean change_station_prev(GtkWidget *widget, GdkEvent *event,
 	    break;
 	}
 	else{
-	    if((app->config->current_station_id) && (station_code) &&
-            	    !strcmp(app->config->current_station_id, station_code))
+	    if((app->config->current_station_name) && (station_name) &&
+            	    !strcmp(app->config->current_station_name, station_name))
 		ready = TRUE;
 	    g_free(station_name);
 	    g_free(station_code);
@@ -194,8 +194,8 @@ gboolean change_station_next(GtkWidget *widget, GdkEvent *event,
 	}
 	else{
 		
-	    if((app->config->current_station_id) && (station_code) &&
-            	    !strcmp(app->config->current_station_id, station_code))
+	    if((app->config->current_station_name) && (station_name) &&
+            	    !strcmp(app->config->current_station_name, station_name))
 		ready = TRUE;
 	    g_free(station_name);
 	    g_free(station_code);
@@ -229,7 +229,7 @@ gboolean change_station_select(GtkWidget *widget, gpointer user_data){
     if (!(app->config->current_station_id) || (!(char*)user_data))
 	return FALSE;
 
-    if(!strcmp((char*)user_data, app->config->current_station_id))
+    if(!strcmp((char*)user_data, app->config->current_station_name))
 	return FALSE;
 
     valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
@@ -240,8 +240,8 @@ gboolean change_station_select(GtkWidget *widget, gpointer user_data){
                             0, &station_name,
                             1, &station_code,
                             -1);
-	if( (station_code) &&
-	    !strcmp((char*)user_data, station_code)){
+	if( (station_name) &&
+	    !strcmp((char*)user_data, station_name)){
         /* update current station code */
             if(app->config->current_station_id)
                 g_free(app->config->current_station_id);
@@ -735,7 +735,8 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
     add_periodic_event(time(NULL));
 */
 #ifdef OS2008
-    initial_gps_connect();
+    app->gps_device = NULL;
+    initial_gps_control();
     app->widget_first_start = FALSE;		     
 
     gtk_widget_set_name(GTK_WIDGET(app->top_widget), PACKAGE_NAME);
@@ -807,7 +808,7 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
     /* remove sensor time */
     if(app->sensor_timer > 0)
 	g_source_remove(app->sensor_timer);
-	deinitial_gps_connect();
+	deinitial_gps_control();
     	g_signal_handler_disconnect(app->parent,app->signal_size_request);
 	g_signal_handler_disconnect(app->parent_parent,app->signal_press);  
 	g_signal_handler_disconnect(app->parent_parent,app->signal_release);   
@@ -894,11 +895,11 @@ void menu_init(void){
 	if(station_name){
 	    gtk_menu_shell_append(GTK_MENU_SHELL(app->contextmenu),
 					menu_item = gtk_menu_item_new_with_label(station_name));
-	    g_free(station_name);
-	    station_name = NULL;
+	    g_free(station_code);
+	    station_code = NULL;
 	}
         g_signal_connect(G_OBJECT(menu_item), "activate",
-                    	    G_CALLBACK(change_station_select), station_code);
+                    	    G_CALLBACK(change_station_select), station_name);
         valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list),
                                                         &iter);
     }
@@ -1677,21 +1678,31 @@ void add_wind_text(GSList *day, gchar *buffer, gboolean is_day){
 	    if (is_day){
 		wind_direction = (char*)hash_table_find(item_value(day, "day_wind_title"), TRUE);
 		sprintf(buffer + strlen(buffer),
-		    "<span foreground='#%02x%02x%02x'>\n%s\n%.1f</span>",
+		    "<span foreground='#%02x%02x%02x'>\n%s\n",
 		    app->config->font_color.red >> 8,
 		    app->config->font_color.green >> 8,
 		    app->config->font_color.blue >> 8,
-		    wind_direction,
-		    convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))));
+		    wind_direction);
+		if (app->config->show_wind_gust)
+		    sprintf(buffer + strlen(buffer),
+			"%.1f</span>",
+			convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))));
+		else
+                    sprintf(buffer + strlen(buffer),"</span>");
 	    }else{
 		wind_direction = (char*)hash_table_find(item_value(day, "night_wind_title"), TRUE);
 		sprintf(buffer + strlen(buffer),
-		    "<span foreground='#%02x%02x%02x'>\n%s\n%.1f</span>",
+		    "<span foreground='#%02x%02x%02x'>\n%s\n",
 		    app->config->font_color.red >> 8,
 		    app->config->font_color.green >> 8,
 		    app->config->font_color.blue >> 8,
-		    wind_direction,
-		    convert_wind_units(app->config->wind_units, atof(item_value(day, "night_wind_speed"))));
+		    wind_direction);
+		if (app->config->show_wind_gust)
+		    sprintf(buffer + strlen(buffer),
+			"%.1f</span>",
+			convert_wind_units(app->config->wind_units, atof(item_value(day, "night_wind_speed"))));
+		else
+                    sprintf(buffer + strlen(buffer),"</span>");
 	    }
     }
 }
@@ -1872,7 +1883,8 @@ omweather_init(OMWeather *applet){
     /* Start main applet */ 
     app->top_widget = gtk_hbox_new(FALSE, 0);
     applet->queueRefresh=TRUE;
-    initial_gps_connect();
+    app->gps_device = NULL;
+    initial_gps_control();
     app->widget_first_start = TRUE;
 
     gtk_widget_set_name(GTK_WIDGET(app->top_widget), PACKAGE_NAME);
@@ -1929,7 +1941,7 @@ omweather_destroy(GtkObject *widget){
     if(app->sensor_timer > 0)
 	g_source_remove(app->sensor_timer);
     
-    deinitial_gps_connect();
+    deinitial_gps_control();
     
     if(app){
 	app->top_widget = NULL;    
