@@ -84,7 +84,7 @@ extern void add_periodic_event(time_t last_update);
 extern time_t calculate_diff_time(int timezone);
 extern void remove_daytime_event(void);
 extern void clean_download(void);
-extern void weather_window_settings(GtkWidget *widget,GdkEvent *event,gpointer user_data);
+extern void weather_window_settings(GtkWidget *widget, gpointer user_data);
 extern int read_config(AppletConfig*);
 extern void config_save(AppletConfig*);
 extern GtkListStore* create_items_list(const char *path, const char *filename,
